import { TabService } from './../../services/tab.service';
import { debounceTime } from 'rxjs/operators';
import { Subject } from 'rxjs';
import { NzMessageService } from 'ng-zorro-antd/message';
import { Component, OnInit, HostListener, AfterViewInit, ViewChild } from "@angular/core";
import { MainService } from 'src/app/services/main.service';
import { ActivatedRoute } from '@angular/router';
import { ToolService } from "../../../../services/tool.service";
import { CustomChangeDateComponent } from '../../components/custom-change-date/custom-change-date.component';
@Component({
  selector: "app-distribution-user-evaluate-statistics",
  templateUrl: "./distribution-user-evaluate-statistics.component.html",
  styleUrls: ["./distribution-user-evaluate-statistics.component.less"],
})
export class DistributionUserEvaluateStatisticsComponent implements OnInit, AfterViewInit {
  @ViewChild('customChangeDate', { static: false }) customChangeDateComponent!: CustomChangeDateComponent;
  constructor(
    private mainService: MainService,
    private message: NzMessageService,
    private route: ActivatedRoute,
    private tabService: TabService,
		private tool: ToolService,
  ) {}

  listOfData: any[] = []; //表格数据
  listOfDataEnd: any[] = []; //表格合计
  pageIndex: number = 1; //表格当前页码
  pageSize: number = 30; //表格每页展示条数
  listLength: number = 0; //表格总数据量

  userId;//人员id

  searchTimerSubject = new Subject();

  ngOnInit() {
    this.searchTimerSubject.pipe(debounceTime(500)).subscribe((v) => {
      let fun = v[0];
      fun.call(this, v[1]);
    });
  }

  ngAfterViewInit(){
    this.initSessionData();
    this.getQueryParams();
    setTimeout(() => {
      this.search();
    }, 0)
    this.onResize();
  }

  tableHeight:number = 0;
  @HostListener('window:resize')
  onResize(): void {
    setTimeout(() => {
      this.tableHeight = window.innerHeight - (document.querySelector('.searchDataWrap') as HTMLElement).offsetHeight - 64 - 36 - 48 - 8 - (document.querySelector('.ant-table-header') as HTMLElement).offsetHeight - 55 - this.getMoreFilter + 14;

    }, 0)
  }

  getQueryParams(){
    let queryParams = this.tabService.getQueryParams();
    this.tabService.clearQueryParams();
    if(queryParams.dateRange){
      this.dateRange = queryParams.dateRange;
      this.customChangeDateComponent.initByDate(this.dateRange);
    }
  }

  get getMoreFilter(){
    let flag = this.fieldConfig.fields.groupDTO || this.fieldConfig.fields.deptDTO;
    return flag ? 37 : 0;
  }

  // 初始化缓存数据
  queryType:any;
  hosId:any;
  dutyId:any;
  parentDutyId:any;
  initSessionData(){
    let newStatistics = JSON.parse(sessionStorage.getItem('newStatistics'));
    let queryType:any = newStatistics.queryType;
    let hosId:any = newStatistics.hospitalId;
    let dutyId:any = newStatistics.dutyId;

    queryType = queryType ? +queryType : undefined;
    hosId = hosId ? +hosId : undefined;
    dutyId = dutyId ? +dutyId : undefined;

    this.queryType = queryType;
    if(queryType == 1){
      this.hosId = undefined;
      this.dutyId = undefined;
      this.parentDutyId = undefined;
    }else if(queryType == 2){
      this.hosId = hosId;
      this.dutyId = undefined;
      this.parentDutyId = undefined;
    }else if(queryType == 3){
      this.hosId = undefined;
      this.dutyId = dutyId;
      this.parentDutyId = undefined;
    }else if(queryType == 4){
      this.hosId = undefined;
      this.dutyId = undefined;
      this.parentDutyId = dutyId;
    }
  }

  get getHosId(){
    return this.parentDutyId || this.dutyId || this.hosId;
  }

  // 表格数据
  loading1 = false;
  getList(num?: number, field?: string, sort?: string) {
    if (num !== undefined) {
      this.pageIndex = num;
    }
    let postData:any = {
      idx: this.pageIndex - 1,
      sum: this.pageSize,
			userId: this.userId || undefined,
			buildingId: this.fieldConfig.fields.buildingId || undefined,
      startDate: this.customChangeDateComponent.startDate || undefined,
      endDate: this.customChangeDateComponent.endDate || undefined,
      hosId: this.getHosId,
      groupId: this.fieldConfig.fields.groupId || undefined,
      deptId: this.fieldConfig.fields.deptId || undefined,
      taskTypeId: this.fieldConfig.fields.taskTypeId || undefined,
      statisticsTypeId: this.fieldConfig.fields.statisticsTypeId || undefined,
    };
    if (field && sort) {
      postData.sort = `${field} ${sort === "ascend" ? `asc` : `desc`}`
    }
    this.loading1 = true;
    this.mainService
      .postCustom("itsm/report", "userDegreeTransOrder", postData)
      .subscribe((result) => {
        this.loading1 = false;
        this.listOfData = result.dataList.filter((v, i) => { return i != result.dataList.length - 1 });
        this.listOfDataEnd = result.dataList.filter((v, i) => { return i == result.dataList.length - 1 });
        this.listLength = result.totalCount;
      });
  }

  // 列表排序
  sortCurrent:any = {};
  sortCurrentKey: string = "";
  sortCurrentValue: string | null = "";
  sort(e) {
    const { key, value } = e;
    this.sortCurrentKey = key;
    this.sortCurrentValue = value;
    this.getList(this.pageIndex, this.sortCurrentKey, this.sortCurrentValue);
  }

  // 搜索
  search() {
    this.getList(1, this.sortCurrentKey, this.sortCurrentValue);
  }

  // 日期选择
  dateRange: any = [];

  // 导出
  excelExportLoading:any = false;
  excelExport(){
    this.excelExportLoading = this.message.loading("导出中..", {
      nzDuration: 0,
    }).messageId;
    let postData:any = {
			userId: this.userId || undefined,
			buildingId: this.fieldConfig.fields.buildingId || undefined,
      startDate: this.customChangeDateComponent.startDate || undefined,
      endDate: this.customChangeDateComponent.endDate || undefined,
      hosId: this.getHosId,
      groupId: this.fieldConfig.fields.groupId || undefined,
      deptId: this.fieldConfig.fields.deptId || undefined,
      taskTypeId: this.fieldConfig.fields.taskTypeId || undefined,
      statisticsTypeId: this.fieldConfig.fields.statisticsTypeId || undefined,
    };
    if (this.sortCurrentKey && this.sortCurrentValue) {
      postData.sort = `${this.sortCurrentKey} ${this.sortCurrentValue === "ascend" ? `asc` : `desc`}`
    }
    this.mainService
      .postExportCustom("itsm/export", "userDegreeTransOrder", postData)
      .subscribe((data) => {
        this.message.remove(this.excelExportLoading);
        this.excelExportLoading = false;
        this.message.success('导出成功');
        var file = new Blob([data], {
          type: "application/vnd.ms-excel",
        });
        //trick to download store a file having its URL
        var fileURL = URL.createObjectURL(file);
        var a = document.createElement("a");
        a.href = fileURL;
        a.target = "_blank";
        a.download = `${this.route.parent.routeConfig.data.title}.xls`;
        document.body.appendChild(a);
        a.click();
      },(err) => {
        this.message.remove(this.excelExportLoading);
        this.excelExportLoading = false;
        this.message.error('导出失败');
      });
  }
  // 重置
  reset(){
    this.sortCurrentKey = "";
		this.sortCurrentValue = "";
		this.sortCurrent = {};
    this.dateRange = []
    this.userId = undefined;
    this.fieldConfig.fields = {groupId: undefined, deptId: undefined, buildingId: undefined, taskTypeId: undefined, statisticsTypeId: undefined};
    this.customChangeDateComponent.resetByDate();
    this.search();
  }

  // 人员搜索
  changeUserInp(e) {
    this.searchTimer(this.getUserList, e);
  }

  // 防抖
  isLoading = false;
  searchTimer(fun, e) {
    this.isLoading = true;
    this.searchTimerSubject.next([fun, e]);
  }

  openChangeUser(flag){
    flag && this.getUserList();
  }

  // 获取人员列表
  userList:any[] = [];
  getUserList(keyword?) {
    let postData: any = {
      idx: 0,
      sum: 20,
      user: {
        name: keyword,
        simpleQuery: true,
        statisticalHosId: this.getHosId,
      },
    };
    this.isLoading = true;
    this.mainService
      .getFetchDataList("simple/data", "user", postData)
      .subscribe((data) => {
        this.isLoading = false;
        this.userList = data.list;
      });
  }

  // 详细搜索
  fieldConfig:any = {
    fields: {groupId: undefined, deptId: undefined, buildingId: undefined, taskTypeId: undefined, statisticsTypeId: undefined},
    config: {group: true, dept: true, building: true, taskType: true, statisticsType: true},
  }
  showSearchMore:boolean = false;
  showMore(){
    this.showSearchMore = true;
  }

  cancelEvent(){
    this.showSearchMore = false;
  }

  submitEvent(fields){
    this.showSearchMore = false;
    this.fieldConfig.fields = fields;
    console.log('this.fieldConfig.fields:', this.fieldConfig.fields)
    this.search();
    this.onResize();
  }
}
